@@ -104,7 +104,9 @@ class Subscription(models.Model):
             params['hub.lease_seconds'] = lease_seconds
 
         credentials = get_hub_credentials(self.hub)
-        response = requests.post(self.hub, data=params, auth=credentials)
+        timeout = getattr(settings, 'PUSH_TIMEOUT', None)
+        response = requests.post(self.hub, data=params, auth=credentials,
+                                 timeout=timeout)
 
         if response.status_code in (202, 204):
             if (
