@@ -1,9 +1,5 @@
-import warnings
-
 from functools import partial
 
-import requests
-
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.utils.crypto import get_random_string
@@ -17,18 +13,6 @@ generate_random_string = partial(
                   '0123456789!@#$%^&*(-_=+)')
 
 
-def get_hub(topic):
-    import feedparser
-    warnings.warn("get_hub is deprecated. Use your own utility function "
-                  "instead.", DeprecationWarning)
-    response = requests.get(topic)
-    parsed = feedparser.parse(response.text)
-    for link in parsed.feed.links:
-        if link['rel'] == 'hub':
-            return link['href']
-    raise TypeError("Hub not found")
-
-
 def hub_credentials(hub_url):
     """A callback that returns no credentials, for anonymous
     subscriptions. Meant to be overriden if developers need to
